@@ -15,7 +15,6 @@ async fn main() {
         }
     }
 
-    // No need to sort since `selectme` is fair by default.
-    // values.sort();
+    values.sort();
     assert_eq!(&[1, 2, 3, 4, 5, 6], &values[..]);
 }
